<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.vsourz.com
 * @since             1.0.4
 * @package           Acf7db_schedule_report
 *
 * @wordpress-plugin
 * Plugin Name:       Schedule Report For Advanced CF7 DB
 * Plugin URI:        https://www.vsourz.com
 * Description:       This plugin is add-on for Advance Contact Form 7 DB plugin. It's generate CSV file on schedule time and send mail to users.
 * Version:           1.0.4
 * Author:            Vsourz Digital
 * Author URI:        https://www.vsourz.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       acf7db_schedule_report
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.1 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'ACF7DB_SCHEDULE_REPORT_VERSION', '1.0.4' );

/**
 * Detect plugin. For use in Admin area only.
 */
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
if(is_plugin_active( 'advanced-cf7-db/advanced-cf7-db.php')){

	if(!defined('VSZ_ACF7DB_ACTIVE')){
		define('VSZ_ACF7DB_ACTIVE',true);
	}

}
else{
	if(!defined('VSZ_ACF7DB_ACTIVE')){
		define('VSZ_ACF7DB_ACTIVE',false);
	}
}

if(!defined('VSZ_ACF7DB_SR_TEXT_DOMAIN')){
	define( 'VSZ_ACF7DB_SR_TEXT_DOMAIN', 'acf7db-schedule-report' );
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-acf7db_schedule_report-activator.php
 */
function activate_acf7db_schedule_report() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-acf7db_schedule_report-activator.php';
	Acf7db_schedule_report_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-acf7db_schedule_report-deactivator.php
 */
function deactivate_acf7db_schedule_report() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-acf7db_schedule_report-deactivator.php';
	Acf7db_schedule_report_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_acf7db_schedule_report' );
register_deactivation_hook( __FILE__, 'deactivate_acf7db_schedule_report' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-acf7db_schedule_report.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_acf7db_schedule_report() {

	$plugin = new Acf7db_schedule_report();
	$plugin->run();

}

run_acf7db_schedule_report();
