<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.vsourz.com
 * @since      1.0.0
 *
 * @package    Acf7db_schedule_report
 * @subpackage Acf7db_schedule_report/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Acf7db_schedule_report
 * @subpackage Acf7db_schedule_report/admin
 * @author     vsourz Digital <support@vsourz.com>
 */
class Acf7db_schedule_report_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Acf7db_schedule_report_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Acf7db_schedule_report_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_register_style( 'acf7db_schedule_report_css', plugin_dir_url( __FILE__ ) . 'css/acf7db_schedule_report-admin.css', array(), $this->version, 'all' );
		wp_register_style( 'acf7db_schedule_select', plugin_dir_url( __FILE__ ) . 'css/multi-select.css', array(), $this->version, 'all' );
		wp_register_style( 'vsz_acf7db_datatables_min_css', plugin_dir_url( __FILE__ ) . 'css/datatables.min.css', array(), $this->version, 'all' );
		//wp_register_style( 'vsz_acf7db_bootstrap_min_css', plugin_dir_url( __FILE__ ) . 'css/bootstrap.min.css', array(), $this->version, 'all' );
		wp_register_style( 'vsz_acf7db_schedule_datetime_css', plugin_dir_url( __FILE__ ) . 'css/jquery.datetimepicker.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Acf7db_schedule_report_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Acf7db_schedule_report_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_register_script( 'vsz_acf7db_schedule_report_js', plugin_dir_url( __FILE__ ) . 'js/acf7db_schedule_report-admin.js', array( 'jquery' ), $this->version, false );
		wp_register_script( 'vsz_acf7db_bootstrap_min_js', plugin_dir_url( __FILE__ ) . 'js/bootstrap.min.js', array( 'jquery' ), $this->version, false );
		wp_register_script( 'vsz_acf7db_multi-select.js', plugin_dir_url( __FILE__ ) . 'js/jquery.multi-select.js', array( 'jquery' ), $this->version, false );
		wp_register_script( 'vsz_acf7db_datatables_min_js', plugin_dir_url( __FILE__ ) . 'js/datatables.min.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( 'vsz_acf7db_schedule_report_run_now_js', plugin_dir_url( __FILE__ ) . 'js/acf7db_schedule_report-run_now.js', array( 'jquery' ), $this->version, false );
		wp_register_script( 'vsz_acf7db_schedule_datetime_js', plugin_dir_url( __FILE__ ) . 'js/jquery.datetimepicker.js', array( 'jquery' ), $this->version, false );

	}


	/************************************** Register custom post type Here**********************************/

	public function vsz_register_acf7db_schedule_report_cpt(){
		$cap_type 	= 'post';
		$plural 	= 'Schedule Reports';
		$single 	= 'Schedule Report';
		$cpt_name 	= 'schedule_report';
		$text_domain = 'acf7db-schedule-report';

		// define labels for show in admin side
		$post_labels = array(
							'name'                  => __( "Schedule Reports", $text_domain ),
							'singular_name'         => __( $single, $text_domain ),
							'add_new'               => __( "Add Schedule", $text_domain ),
							'add_new_item'          => __( "Add Schedule", $text_domain ),
							'edit_item'             =>  __( "Edit Schedule" , $text_domain ),
							'new_item'              => __( "New Schedule", $text_domain ),
							'all_items' 			=> __( $plural, $text_domain ),
							'view_item'             => __( "View {$single}", $text_domain ),
							'search_items'          => __( "Search {$plural}", $text_domain ),
							'not_found'             => __( "No {$plural} Found", $text_domain ),
							'not_found_in_trash'    => __( "No {$plural} Found in Trash", $text_domain ),
						);


		// define which arguments are passed in custom posts type and used.
		$post_args = array(
						'labels'                => $post_labels,
						'public'                => false,
						'show_ui'               => true,
						'show_in_nav_menus'		=> false,
						'publicly_queryable' 	=> false,
						'capability_type'       => 'post',
						'menu_icon'				=> 'dashicons-analytics',
						'menu_position'			=> 80,
						'exclude_from_search' 	=> true,
						'hierarchical' 			=> false,
						'has_archive' 			=> false,
						'supports'              => array( 'title'),
						'query_var'				=> true,
						'show_in_rest' 			=> true,
						'show_in_menu'   		=> false
					);
		if(defined('VSZ_ACF7DB_ACTIVE') && VSZ_ACF7DB_ACTIVE === false){
			$post_args['show_in_menu'] = true;
		}
		// register custom post type
		if(is_admin()){
			register_post_type(strtolower( $cpt_name ),$post_args);
		}
	}

	//add submenu
	public function vsz_register_acf7db_schedule_report_cpt_sub_menu(){

		if(defined('VSZ_ACF7DB_ACTIVE') && VSZ_ACF7DB_ACTIVE){
			if(is_admin()){
					add_submenu_page(
						'contact-form-listing',                 			// parent slug
						__('Schedule Reports',VSZ_ACF7DB_SR_TEXT_DOMAIN),   // page title
						__('Schedule Reports',VSZ_ACF7DB_SR_TEXT_DOMAIN),   // sub-menu title
						'edit_posts',                 // capability
						'edit.php?post_type=schedule_report' // your menu menu slug
					);

			}
		}
	}

	//Register all meta boxes here
	public function vsz_acf7db_schedule_report_register_metaboxes(){

		$cpt_name 	= 'schedule_report';
		$text_domain =VSZ_ACF7DB_SR_TEXT_DOMAIN;

		//Display Schedule information
		add_meta_box(
			'vsz_acf7db_schedule_details',__( 'Schedule Details', $text_domain),
			array($this,'vsz_acf7db_schedule_details_callback'),
			$cpt_name,'normal','high');

		//Display Schedule information
		add_meta_box(
			'vsz_acf7db_contact_form_details',__( 'Contact Form Details', $text_domain),
			array($this,'vsz_acf7db_contact_form_details_callback'),
			$cpt_name,'normal','high');

		//Display Email Templates information
		add_meta_box(
			'vsz_acf7db_schedule_email_manager',__( 'Email Manager', $text_domain),
			array($this,'vsz_acf7db_schedule_email_manager_callback'),
			$cpt_name,'normal','high');

		//Display Report History information
		add_meta_box(
			'vsz_acf7db_schedule_report_history',__( 'Report History', $text_domain),
			array($this,'vsz_acf7db_schedule_report_history_callback'),
			$cpt_name,'normal','high');

		//Delete Forms and its data
		add_meta_box(
			'vsz_acf7db_schedule_delete',__( 'Delete Records', $text_domain),
			array($this,'vsz_acf7db_schedule_delete_records_callback'),
			$cpt_name,'normal','high');

	}

	//Display Schedule information here
	public function vsz_acf7db_schedule_details_callback($post){
		include(plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/vsz_acf7db_schedule_details.php');
	}

	//Display Email Templates information here
	public function vsz_acf7db_schedule_email_manager_callback($post){
		include(plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/vsz_acf7db_schedule_email_manager.php');
	}
	//Display Report History information here
	public function vsz_acf7db_schedule_report_history_callback($post){
		include(plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/vsz_acf7db_schedule_report_history.php');
	}
	//Display Email Templates information here
	public function vsz_acf7db_contact_form_details_callback($post){
		include(plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/vsz_acf7db_contact_form_details.php');
	}
	//Display Delete records here
	public function vsz_acf7db_schedule_delete_records_callback($post){
		include(plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/acf7db_schedule_report-delete-settings.php');
	}

	//Change post place holder title here
	public function vsz_acf7db_schedule_report_change_title( $input ) {

		global $post_type;
		$cpt_name 	= 'schedule_report';
		$text_domain =VSZ_ACF7DB_SR_TEXT_DOMAIN;

		if( is_admin() && $cpt_name == $post_type ){
			return apply_filters('vsz_acf7db_change_placeholder_title','Schedule Title');
		}
		return $input;
	}

	//Add custom class in body tag with related plugin screen
	function vsz_acf7db_schedule_report_add_classes( $classes ){

		global $post_type;
		$cpt_name 	= 'schedule_report';
		$text_domain =VSZ_ACF7DB_SR_TEXT_DOMAIN;
		if( is_admin() && $cpt_name == $post_type ){
			// Right: Add a leading space and a trailing space.
			$classes  .= apply_filters('vsz_acf7db_add_plugin_class','acf7db-schedule-report');
		}
		return $classes;
	}

	//Save schedule information here
	public function vsz_acf7db_schedule_save_details($post_id, $post, $update){
		include_once plugin_dir_path( __FILE__ ) . 'partials/vsz_acf7db_schedule_save_details.php';
	}
	// Display server side validation message
	function vsz_acf7db_schedule_error_notice($m){
		global $post;
		if(empty($post)){
			return;
		}
		if(isset($post->post_type) && $post->post_type != "schedule_report"){
			return;
		}

		$notice = get_option('otp_notice');

		if (!empty($notice)){
			foreach($notice as $pid => $m){
				$status = get_post_status($pid);

				if($status != 'publish'){
					$class = 'notice error is-dismissible';
				}else{
					$class = ' notice updated is-dismissible';
				}
				if ($post->ID == $pid && $m != "Post updated."){

					if(is_array($m)){

						foreach ($m as $key => $value) {

							echo '<div id="message" class="'.$class.' vsz-error"><p>'.__($value,VSZ_ACF7DB_SR_TEXT_DOMAIN).'</p></div>';

						}

					}else{

						echo '<div id="message" class="'.$class.'"><p>'.__($m,VSZ_ACF7DB_SR_TEXT_DOMAIN).'</p></div>';

					}

					//make sure to remove notice after its displayed so its only displayed when needed.
					unset($notice[$pid]);
					update_option('otp_notice',$notice);
					break;
				}
			}
		}
		$notice1 = get_option('otp_notice_success');
		if (!empty($notice1)){
			foreach($notice1 as $pid => $m){
				if ($post->ID == $pid ){
					echo '<div id="message" class="updated notice notice-success is-dismissible"><p>'.__($m,VSZ_ACF7DB_SR_TEXT_DOMAIN).'</p></div>';
					//make sure to remove notice after its displayed so its only displayed when needed.
					unset($notice1[$pid]);
					update_option('otp_notice_success',$notice1);
					break;
				}
			}
		}
	}
	// remove post draft updated message
	function vsz_acf7db_post_published( $messages )
	{
		global $post;
		if(isset($post->post_type) && $post->post_type == "schedule_report"){
			unset($messages[$post->ID]);
			//unset($messages['post']['1']); ///// when post added
			//unset($messages['post']['6']); //// when post published
			//unset($messages['post']['8']); //// when post submitted
			unset($messages['post']['10']); //// when post draft updated
		}
		return $messages;
	}
	// Display Schedule Information On Listing
	function vsz_acf7db_schedule_columns( $columns ) {
		$result = array_slice($columns , 0 ,1) +
					array( "title" => ( 'Name' ) ) +
					array_slice($columns, 1 , 1 ) +
					array(   "schedule_timing" => __( 'Schedule Timing',VSZ_ACF7DB_SR_TEXT_DOMAIN ) ,"enquiry_form_report" => __( 'Enquiry Form Report',VSZ_ACF7DB_SR_TEXT_DOMAIN ),"run_now" => __( 'Run Now',VSZ_ACF7DB_SR_TEXT_DOMAIN ),"next_schedule" => __( 'Next Schedule',VSZ_ACF7DB_SR_TEXT_DOMAIN ) ) +
					array_slice($columns, 2 , 2 );
			$columns = $result;

		return $columns;
	}

	// Display run now button
	function vsz_acfdb_run_now_btn($post){
		
	}

	function vsz_acf7db_schedule_custom_columns($columns, $post_id){
		$out = '';
		global $wpdb;
		//define function for set current site time zone 
		vsz_schedule_report_get_site_time_zone();
		switch( $columns ) {



			/* If displaying the 'Projects Count' column. */
			case 'schedule_timing' :
				/* If no post found, output a default message.
					The projects have been counted according to the roles of the members
				*/
				$schedule_time = '-';
				$schedule_time = get_post_meta($post_id,'schedule_time',true);
				echo $schedule_time;

				break;

			/* If displaying the 'E-mail' column. */
			case 'enquiry_form_report' :
				/*	If no post found, output a default message.

				*/
				$schedule_form_id = '';
				$schedule_form_id = get_post_meta($post_id , 'schedule_form_id' , true);
				if(empty($schedule_form_id)){
					echo '-';
					break;
				}
				$schedule_form_title = get_the_title($schedule_form_id);
				echo $schedule_form_title;
				break;
			
			/* If displaying the 'E-mail' column. */
			case 'run_now' :
				/*	If no post found, output a default message.

				*/
				$post_status = get_post_status($post_id);
				if($post_status == "publish"){
					?><div class="run-now-sec">
						<input type="button" class="form-control button acf7_db_schedule_run_now" data-id="<?php echo $post_id; ?>" value="<?php _e('Run Now',VSZ_ACF7DB_SR_TEXT_DOMAIN); ?>" />
					</div><?php
					break;
				}
				break;
			
			/* If displaying the 'E-mail' column. */
			case 'next_schedule' :
				/*	If no post found, output a default message.

				*/
				$next_schedule = '';
				$next_schedule = get_post_meta($post_id , 'next_schedule' , true);
				if(empty($next_schedule)){
					echo '-';
					break;
				}
				echo date('d/m/Y H:i',$next_schedule);
				break;

				break;

			/* Just break out of the switch statement for everything else. */
			default :
				break;
		}
		return $out;
	}
	// cron schedule filter
	public function vsz_schedules( $schedules ) {
		$vsz_scheds = '';
		$vsz_scheds = get_option( 'vsz_cron_schedules', array() );
		$quick_view_cron = 	array(
								'vsz_quickview_delete' => array (
									'interval' => 86400,
									'display' => 'Quick View Delete Cron',
								)
							);
		$schedules = array_merge($quick_view_cron,$schedules);
		if(empty($vsz_scheds)){
			return $schedules;
		}
		return array_merge( $vsz_scheds, $schedules );
	}
	///Contact forms fileds ajax callback
	public function vsz_cron_schedules_contact_fields(){
		$contact_form_id = $_POST['form_id'];
		$fields = vsz_cf7_get_db_fields($contact_form_id,false);
		if(isset($fields) && !empty($fields)){
			foreach($fields as $field_data){
				?><option value="<?php echo $field_data;?>"><?php echo $field_data;?></option><?php
			}
		}
		wp_die();
	}

	// cron schedule hooks
	public function vsz_cron_schedules_hooks_callback($post_id,$runNowFlag=false){
		global $wpdb;
		$post_status = get_post_status($post_id);
		if($post_status != 'publish'){
			return;
		}
		//define function for set current site time zone 
		vsz_schedule_report_get_site_time_zone();
		$arrMeta = get_post_meta($post_id);
		$arrMeta['vsz_post_id'] = $post_id;
		$schedule_end_date = isset($arrMeta['schedule_end_date']) ? sanitize_text_field($arrMeta['schedule_end_date'][0]) : '';
		$form_id = $arrMeta['schedule_form_id'][0];
		$schedule_email_active = $arrMeta['schedule_email_active'][0];
		// check schedule enddate
		if(!empty($schedule_end_date)){
			$currnt_date = date('Y-m-d');

			$currnt_date_formate = DateTime::createFromFormat('Y-m-d', $currnt_date);

			$schedule_end_date_formate = DateTime::createFromFormat('Y-m-d', $schedule_end_date);

			$currnt_date_formate_new = $currnt_date_formate->format('Y-m-d');
			$schedule_end_date_formate_new = $schedule_end_date_formate->format('Y-m-d');

			$check_current_date = new DateTime($currnt_date_formate_new);
			$check_schedule_end_date = new DateTime($schedule_end_date_formate_new);

			if($check_current_date >  $check_schedule_end_date){
				wp_clear_scheduled_hook( 'vsz_cron_schedules_hooks', array("id"=>$post_id) );
			}
			else{
				/*
				 * Checking if the schedule option is to export or delete
				 * Based on the selection done export or delete func done
				 *
				 * @since 1.0.3
				 */

				$schedule_option = isset($arrMeta['schedule_option']) ? sanitize_text_field($arrMeta['schedule_option'][0]) : '';
				if($schedule_option == ''){
					$schedule_option = "export";
				}
				if($schedule_option == "export"){
					//Checking if the email is active or not and add send mail accordingly
					if(isset($schedule_email_active) && !empty($schedule_email_active) && $schedule_email_active == 'active'){
						if(isset($arrMeta["schedule_file_type"]) && $arrMeta["schedule_file_type"][0] == "excel-xls"){
							vsz_scheduled_cf7_export_to_excel($form_id,'',$arrMeta,"Excel5");
						}
						else if(isset($arrMeta["schedule_file_type"]) && $arrMeta["schedule_file_type"][0] == "excel-xlsx"){
							vsz_scheduled_cf7_export_to_excel($form_id,'',$arrMeta,"Excel2007");
						}
						else{
							vsz_scheduled_cf7_export_to_csv($form_id,'',$arrMeta);
						}
						if(!$runNowFlag){
							//update next schedule date
							$next_schedule = wp_next_scheduled( 'vsz_cron_schedules_hooks', array("id"=>$post_id) );
							update_post_meta($post_id,'next_schedule',$next_schedule);
						}
					}
				}
				//Check if delete
				if($schedule_option == "delete"){
					$delete_day = isset($arrMeta['delete_day']) ? sanitize_text_field($arrMeta['delete_day'][0]) : '';
					$delete_day_number = isset($arrMeta['delete_day_number']) ? sanitize_text_field($arrMeta['delete_day_number'][0]) : '';
					$schedule_delete_form_id = isset($arrMeta['schedule_delete_form_id']) ? sanitize_text_field($arrMeta['schedule_delete_form_id'][0]) : '';
					/*
					 * Deletion starts from here
					 * Checking if the above values are not empty
					 * @since 1.0.3
					 */
					if(!empty($delete_day) && !empty($delete_day_number) && !empty($schedule_delete_form_id)){
						$start_date = date('Y-m-d');
						$date = strtotime($start_date);
						$saved_date = "-".$delete_day_number." ".$delete_day;
						$delete_before_date = date('Y-m-d H:i:s',strtotime($saved_date, $date));

						//Fetch the unique records from the database
						//Creating the custom Query based on the delete date selected
						$search_date_query = "AND `".VSZ_CF7_DATA_ENTRY_TABLE_NAME."`.`name` = 'submit_time' AND `".VSZ_CF7_DATA_ENTRY_TABLE_NAME."`.value  <= '".$delete_before_date."'";
						$query = "SELECT `data_id` FROM `".VSZ_CF7_DATA_ENTRY_TABLE_NAME."` WHERE `cf7_id` IN (".$schedule_delete_form_id.") ".$search_date_query."  GROUP BY `data_id` ";

						$data_delete = $wpdb->get_results($query);
						vsz_delete_records($data_delete);
					}
				}
			}
		}
		else{
			if(isset($schedule_email_active) && !empty($schedule_email_active) && $schedule_email_active == 'active'){
				if(isset($arrMeta["schedule_file_type"]) && $arrMeta["schedule_file_type"] == "excel-xls"){
					vsz_scheduled_cf7_export_to_excel($form_id,'',$arrMeta,"Excel5");
				}
				else if(isset($arrMeta["schedule_file_type"]) && $arrMeta["schedule_file_type"] == "excel-xlsx"){
					vsz_scheduled_cf7_export_to_excel($form_id,'',$arrMeta,"Excel2007");
				}
				else{
					vsz_scheduled_cf7_export_to_csv($form_id,'',$arrMeta);
				}

				if(!$runNowFlag){
					//update next schedule date
					$next_schedule = wp_next_scheduled( 'vsz_cron_schedules_hooks', array("id"=>$post_id) );
					update_post_meta($post_id,'next_schedule',$next_schedule);
				}
			}
		}
	}

	///// Delete cron when delete scadule
	public function vsz_cron_schedules_delete($post_id){
		if ( wp_is_post_revision( $post_id ) )
			return;

			$post_type = get_post_type($post_id);
			// if post type scadule report than delete cron
			if($post_type == 'schedule_report'){
				wp_clear_scheduled_hook( 'vsz_cron_schedules_hooks', array("id"=>$post_id) );
			}
	}

	//Display plugin active or inactive error message
	function vsz_acf7db_plugin_display_message(){
		$text_domain = VSZ_ACF7DB_SR_TEXT_DOMAIN;
		if(defined('VSZ_ACF7DB_ACTIVE') && VSZ_ACF7DB_ACTIVE === false && is_admin())
		{
			echo '<div class="notice error"><p>';
			printf(__('If you want to use ACF7 DB Schedule Report plugin then, you must install <a href="https://wordpress.org/plugins/advanced-cf7-db/" target="_blank">Advanced CF7 DB</a> plugin first.',$text_domain));
			echo '</p></div>';
		}
	}

	// Contact forms fileds ajax callback
	public function acf7db_sr_delete_file_report_callback(){
		include(plugin_dir_path( __FILE__  ) . 'partials/acf7db_sr_delete_file_report.php');
		wp_die();
	}

	// Run Now
	public function acf7db_sr_run_now_callback(){
		$this->vsz_cron_schedules_hooks_callback($_POST["post_id"],true);
		echo "y";
		wp_die();
	}

	// Quick View
	public function acf7db_sr_quick_view_callback(){
		// Calling quick view function
		$post_id = isset($_POST["post_ID"]) ? $_POST["post_ID"] : "";
		$final_rules = array();
		
		$arrMeta = get_post_meta($post_id);
		$arrMeta['vsz_post_id'] = $post_id;

		$finalArr = array();
		$rules = isset($_POST['schedule_contact_form_rule']) ? $_POST['schedule_contact_form_rule'] : "";
		$schedule_file_type = isset($_POST['schedule_file_type']) ? $_POST['schedule_file_type'] : "";

		for($i = 0; $i < count($rules)-4; $i++){
			$fields_name = $rules[$i]["fields_name"];
			$i++;
			$fields_condition = $rules[$i]["fields_condition"];
			$i++;
			$fields_value = $rules[$i]["fields_value"];

			$final_rules[] = array("fields_name"=>$fields_name,"fields_condition"=>$fields_condition,"fields_value"=>$fields_value);
		}

		$schedule_contact_form_rule = isset($_POST['schedule_contact_form_rule']) ? $final_rules : $arrMeta['schedule_contact_form_rule'][0];
		$schedule_type = isset($_POST['schedule_type']) ? $_POST['schedule_type'] : $arrMeta['schedule_type'][0];
		$schedule_repeat = isset($_POST['schedule_repeat']) ? $_POST['schedule_repeat'] : $arrMeta['schedule_repeat'][0];
		$schedule_time = isset($_POST['schedule_time']) ? $_POST['schedule_time'] : $arrMeta['schedule_time'][0];
		$schedule_end_date = isset($_POST['schedule_end_date']) ? $_POST['schedule_end_date'] : $arrMeta['schedule_end_date'][0];
		$schedule_form_id = isset($_POST['schedule_form_id']) ? $_POST['schedule_form_id'] : $arrMeta['schedule_form_id'][0];

		//check end date validation
		$s_end_date = '';
		if(!empty($schedule_end_date)){
			$s_end_date = date_create_from_format("d/m/Y",$schedule_end_date);
			if(!empty($s_end_date)){
				//Get end date information
				$s_end_date =  date_format($s_end_date,"Y-m-d");
			}
		}

		// Override rules
		$arrMeta["schedule_contact_form_rule"] = $schedule_contact_form_rule;
		$arrMeta["schedule_type"][0] = $schedule_type;
		$arrMeta["schedule_repeat"][0] = $schedule_repeat;
		$arrMeta["schedule_time"][0] = $schedule_time;
		$arrMeta["schedule_end_date"][0] = $s_end_date;

		if($schedule_file_type == "excel-xls"){
			$ret = vsz_quick_view_cf7_export_to_excel($schedule_form_id,'',$arrMeta,"Excel5");
		}
		else if($schedule_file_type == "excel-xlsx"){
			$ret = vsz_quick_view_cf7_export_to_excel($schedule_form_id,'',$arrMeta,"Excel2007");
		}
		else{
			$ret = vsz_quick_view_cf7_export_to_csv($schedule_form_id,'',$arrMeta);
		}

		if($ret == "n"){
			echo "n@@~~@@";
		}
		else{
			echo "y@@~~@@".$ret;
		}
		wp_die();
	}

	// Remove file which created more than 24 hour in past
	function vsz_quickview_delete_callback_func(){

		// Get temp dir parh
		$upload_dir = wp_upload_dir();
		$vsz_user_gallery_folder = "ScheduleReport";
		$temp_dir_path = $upload_dir['basedir'].'/'.$vsz_user_gallery_folder.'/QuickView';

		// Pattern to check which type files will be deleted
		$file_type = "/\.(csv)$/";

		// Open handler
		if (($handle = opendir($temp_dir_path)) != false) {

			// Check for every file in the folder
			while (($file = readdir($handle)) != false) {
				$filename = "$temp_dir_path/$file";

				// If file modified time is older than 24 hours than it will be removed
				if (strtotime("-24 hours") >= filemtime($filename) && preg_match($file_type, $filename)) {
					unlink($filename); // Removing the file
				}
			}

			// Close handler
			closedir($handle);
		}
	}

}//End of class

// Generate CSV file for quick view
function vsz_quick_view_cf7_export_to_csv($fid, $ids_export = '',$arrMeta){
    global $wpdb;

	$fid = intval($fid);
	$schedule_post_id = $arrMeta['vsz_post_id'];
	$schedule_contact_form_field = get_post_meta($schedule_post_id,'schedule_contact_form_field',true);
	if(isset($schedule_contact_form_field) && !empty($schedule_contact_form_field)){
		foreach($schedule_contact_form_field as $data){
			$fields[$data] = $data;
		}
	}
	else{
		$fields = vsz_cf7_get_db_fields($fid);
	}

	//Get form id related contact form object
	$obj_form = vsz_cf7_get_the_form_list($fid);
	//get current form title
	$form_title = esc_html($obj_form[0]->title());
	//Get export data
	$data = create_scheduled_export_query($fid, $ids_export, 'data_id desc',$arrMeta);
	//Setup export data
	$data_sorted = wp_unslash(vsz_cf7_sortdata($data));

	// Number results
	$num_results = 0;

	//Generate CSV file
	$timeStamp = date('Ymdhis');
	$schedule_type = $arrMeta['schedule_type'][0];
	$upload_dir = wp_upload_dir();
	$newFileName = 'schedule-report-'.$schedule_post_id.'-'.$timeStamp.'.csv';
	// $exportedFileName = plugin_dir_path( dirname( __FILE__ ) ) . 'admin/export/csv/'.$newFileName;
	$exportedFileName = $upload_dir['basedir'] . '/ScheduleReport/QuickView/'.$newFileName;
	$exportedFileUrl = $upload_dir['baseurl'] . '/ScheduleReport/QuickView/'.$newFileName;

    $fp = fopen($exportedFileName, 'w');

	// fputs($fp, "\xEF\xBB\xBF");

    fputcsv($fp, array_values(array_map('sanitize_text_field',$fields)));
    foreach ($data_sorted as $k => $v){
        $temp_value = array();
        foreach ($fields as $k2 => $v2){
            $temp_value[] = ((isset($v[$k2])) ? html_entity_decode($v[$k2]) : '');
        }
        fputcsv($fp, $temp_value);
		$num_results++;
    }

    fclose($fp);
	if($num_results>0){
		return $exportedFileUrl;
	}
	else{
		return "n";
	}

}

// Generate CSV file for quick view
function vsz_quick_view_cf7_export_to_excel($fid, $ids_export = '',$arrMeta, $excel_type='Excel5'){
	global $wpdb;

	$fid = intval($fid);
	$schedule_post_id = $arrMeta['vsz_post_id'];
	$schedule_contact_form_field = get_post_meta($schedule_post_id,'schedule_contact_form_field',true);
	if(isset($schedule_contact_form_field) && !empty($schedule_contact_form_field)){
		foreach($schedule_contact_form_field as $data){
			$fields[$data] = $data;
		}
	}else{
		$fields = vsz_cf7_get_db_fields($fid);
	}

	//Get form id related contact form object
	$obj_form = vsz_cf7_get_the_form_list($fid);
	//get current form title
	$form_title = esc_html($obj_form[0]->title());
	//Get export data
	// $data = create_export_query($fid, $ids_export, 'data_id desc');
	$data = create_scheduled_export_query($fid, $ids_export, 'data_id desc',$arrMeta);

	// Number results
	$num_results = 0;

	if(!empty($data)){
		//Setup export data
		$data_sorted = wp_unslash(vsz_cf7_sortdata($data));

		$arrHeader = array_values(array_map('sanitize_text_field',$fields));

		//Check that the class exists before trying to use it
		if(!class_exists('PHPExcel')){

			//Include excel class file
			require_once(dirname(__FILE__).'/class/PHPExcel.php');

			//create excel class object
			$xls = new PHPExcel($form_title);

			//First we will set header in excel file
			$col = 0;
			$row = 1;
			foreach($arrHeader as $colName){
				$cell = $xls->getCellNo($row, $col);
				$xls->setActiveSheetIndex(0)->setCellValue($cell,$colName);
				$col++;
			}

			$row = 2;
			foreach ($data_sorted as $k => $v){
				//Define column index here
				$col=0;

				//Get column order wise value here
				foreach ($fields as $k2 => $v2){
					$colVal = (isset($v[$k2]) ? $v[$k2] : '');
					$cell = $xls->getCellNo($row, $col);
					$xls->setActiveSheetIndex(0)->setCellValue($cell,$colVal);
					$col++;
				}
				//Consider new row for each entry here
				$row++;
				// Number results
				$num_results++;
			}

			// Set active sheet index to the first sheet, so Excel opens this as the first sheet
			$xls->setActiveSheetIndex(0);
			
			$upload_dir = wp_upload_dir();
			$schedule_type = $arrMeta['schedule_type'][0];
			$timeStamp = date('Ymdhis');
			
			if($excel_type == "Excel5"){
				$newFileName = 'schedule-report-'.$schedule_post_id.'-'.$timeStamp.'.xls';
			}
			else{
				$newFileName = 'schedule-report-'.$schedule_post_id.'-'.$timeStamp.'.xlsx';
			}
			
			// Safely output the header first and set the fileName also
			$xls->headers($form_title,$excel_type);

			$exportedFileName = $upload_dir['basedir'] . '/ScheduleReport/QuickView/'.$newFileName;
			$exportedFileUrl = $upload_dir['baseurl'] . '/ScheduleReport/QuickView/'.$newFileName;

			//Download excel file here
			$objWriter = PHPExcel_IOFactory::createWriter($xls,$excel_type);
			$objWriter->save($exportedFileName);

			$parameters = array("schedule_email_active" => $arrMeta['schedule_email_active'][0],
								"schedule_from_name" => $arrMeta['schedule_from_name'][0],
								"schedule_from_email" => $arrMeta['schedule_from_email'][0],
								"schedule_contentType" => $arrMeta['schedule_contentType'][0],
								"schedule_subject" => $arrMeta['schedule_subject'][0],
								"schedule_to" => $arrMeta['schedule_to'][0],
								"schedule_message_body" => $arrMeta['schedule_message_body'][0],
								"number_results" => $num_results,
								"attachment"=>$exportedFileName);

			//check email class exist or not
			if(class_exists('scheduled_report_emailclass')){
				$newObj = new scheduled_report_emailclass();
				//send mail from here
				$result = $newObj->scheduled_report($parameters);
			}
		}
	}

	if($num_results>0){
		return $exportedFileUrl;
	}
	else{
		return "n";
	}
}

//Generate CSV file here
function vsz_scheduled_cf7_export_to_csv($fid, $ids_export = '',$arrMeta){
    global $wpdb;
    //set website time zone from here 
	vsz_schedule_report_get_site_time_zone();

	$fid = intval($fid);
	$schedule_post_id = $arrMeta['vsz_post_id'];
	$schedule_contact_form_field = get_post_meta($schedule_post_id,'schedule_contact_form_field',true);
	if(isset($schedule_contact_form_field) && !empty($schedule_contact_form_field)){
		foreach($schedule_contact_form_field as $data){
			$fields[$data] = $data;
		}
	}else{
		$fields = vsz_cf7_get_db_fields($fid);
	}

	//Get form id related contact form object
	$obj_form = vsz_cf7_get_the_form_list($fid);
	//get current form title
	$form_title = esc_html($obj_form[0]->title());
	//Get export data
	$data = create_scheduled_export_query($fid, $ids_export, 'data_id desc',$arrMeta);
	//Setup export data
	$data_sorted = wp_unslash(vsz_cf7_sortdata($data));

	// Number results
	$num_results = 0;

	//Generate CSV file
	$timeStamp = date('Ymdhis');
	$schedule_type = $arrMeta['schedule_type'][0];
	$upload_dir = wp_upload_dir();
	$newFileName = 'schedule-report-'.$schedule_post_id.'-'.get_the_title($fid).'-'.$schedule_type.'-'.$timeStamp.'.csv';
	// $exportedFileName = plugin_dir_path( dirname( __FILE__ ) ) . 'admin/export/csv/'.$newFileName;
	$exportedFileName = $upload_dir['basedir'] . '/ScheduleReport/'.$newFileName;

    $fp = fopen($exportedFileName, 'w');
   // fputs($fp, "\xEF\xBB\xBF");

    fputcsv($fp, array_values(array_map('sanitize_text_field',$fields)));
    foreach ($data_sorted as $k => $v){
        $temp_value = array();
        foreach ($fields as $k2 => $v2){
            $temp_value[] = ((isset($v[$k2])) ? htmlspecialchars_decode($v[$k2]) : '');
        }
        fputcsv($fp, $temp_value);
		$num_results++;
    }

    fclose($fp);

	$parameters = array("schedule_email_active" => $arrMeta['schedule_email_active'][0],
						"schedule_from_name" => $arrMeta['schedule_from_name'][0],
						"schedule_from_email" => $arrMeta['schedule_from_email'][0],
						"schedule_contentType" => $arrMeta['schedule_contentType'][0],
						"schedule_subject" => $arrMeta['schedule_subject'][0],
						"schedule_to" => $arrMeta['schedule_to'][0],
						"schedule_message_body" => $arrMeta['schedule_message_body'][0],
						"number_results" => $num_results,
						"attachment"=>$exportedFileName);

	//check email class exist or not
	if(class_exists('scheduled_report_emailclass')){
		$newObj = new scheduled_report_emailclass();
		//send mail from here
		$result = $newObj->scheduled_report($parameters);
	}
}

//Generate excel file here
function vsz_scheduled_cf7_export_to_excel($fid, $ids_export = '',$arrMeta,$excel_type='Excel5'){
	global $wpdb;

	$fid = intval($fid);
	$schedule_post_id = $arrMeta['vsz_post_id'];
	$schedule_contact_form_field = get_post_meta($schedule_post_id,'schedule_contact_form_field',true);
	if(isset($schedule_contact_form_field) && !empty($schedule_contact_form_field)){
		foreach($schedule_contact_form_field as $data){
			$fields[$data] = $data;
		}
	}else{
		$fields = vsz_cf7_get_db_fields($fid);
	}

	//Get form id related contact form object
	$obj_form = vsz_cf7_get_the_form_list($fid);
	//get current form title
	$form_title = esc_html($obj_form[0]->title());
	$form_title = str_replace(" ","_",$form_title);

	//Get export data
	// $data = create_export_query($fid, $ids_export, 'data_id desc');
	$data = create_scheduled_export_query($fid, $ids_export, 'data_id desc',$arrMeta);

	// Number results
	$num_results = 0;

	if(!empty($data)){
		//Setup export data
		$data_sorted = wp_unslash(vsz_cf7_sortdata($data));

		$arrHeader = array_values(array_map('sanitize_text_field',$fields));

		//Check that the class exists before trying to use it
		if(!class_exists('PHPExcel')){

			//Include excel class file
			require_once(dirname(__FILE__).'/class/PHPExcel.php');
			//create excel class object
			$xls = new PHPExcel($form_title);

			//First we will set header in excel file
			$col = 0;
			$row = 1;
			foreach($arrHeader as $colName){
				$cell = $xls->getCellNo($row, $col);
				$xls->setActiveSheetIndex(0)->setCellValue($cell,$colName);
				$col++;
			}

			$row = 2;
			foreach ($data_sorted as $k => $v){
				//Define column index here
				$col=0;
				//Get column order wise value here
				foreach ($fields as $k2 => $v2){
					$colVal = (isset($v[$k2]) ? html_entity_decode($v[$k2]) : '');
					$cell = $xls->getCellNo($row, $col);
					$xls->setActiveSheetIndex(0)->setCellValue($cell,$colVal);
					$col++;
				}
				//Consider new row for each entry here
				$row++;

				// Number results
				$num_results++;
			}

			// Set active sheet index to the first sheet, so Excel opens this as the first sheet
			$xls->setActiveSheetIndex(0);

			// Safely output the header first and set the fileName also
			$xls->headers($form_title);

			$upload_dir = wp_upload_dir();
			$schedule_type = $arrMeta['schedule_type'][0];
			$timeStamp = date('Ymdhis');

			if($excel_type == "Excel5"){
				$newFileName = 'schedule-report-'.$schedule_post_id.'-'.get_the_title($fid).'-'.$schedule_type.'-'.$timeStamp.'.xls';
			}
			else{
				$newFileName = 'schedule-report-'.$schedule_post_id.'-'.get_the_title($fid).'-'.$schedule_type.'-'.$timeStamp.'.xlsx';
			}
			
			$exportedFileName = $upload_dir['basedir'] . '/ScheduleReport/'.$newFileName;

			//Download excel file here
			$objWriter = PHPExcel_IOFactory::createWriter($xls,$excel_type);
			$objWriter->save($exportedFileName);
			$parameters = array("schedule_email_active" => $arrMeta['schedule_email_active'][0],
								"schedule_from_name" => $arrMeta['schedule_from_name'][0],
								"schedule_from_email" => $arrMeta['schedule_from_email'][0],
								"schedule_contentType" => $arrMeta['schedule_contentType'][0],
								"schedule_subject" => $arrMeta['schedule_subject'][0],
								"schedule_to" => $arrMeta['schedule_to'][0],
								"schedule_message_body" => $arrMeta['schedule_message_body'][0],
								"number_results" => $num_results,
								"attachment"=>$exportedFileName);

			//check email class exist or not
			if(class_exists('scheduled_report_emailclass')){
				$newObj = new scheduled_report_emailclass();
				//send mail from here
				$result = $newObj->scheduled_report($parameters);
			}
		}
	}
}

//Setup export related query here
function create_scheduled_export_query($fid,$ids_export,$cf7d_entry_order_by,$arrMeta){

	global $wpdb;
	$fid = intval($fid);
	//set website time zone from here 
	vsz_schedule_report_get_site_time_zone();
	//Set start date according to scadule type and scadule repeat
	$schedule_type = $arrMeta['schedule_type'][0];
	$schedule_repeat = $arrMeta['schedule_repeat'][0];
	$interval = '';

	if($schedule_type == 'daily'){
		$interval = $schedule_repeat * 86400;
	}
	if($schedule_type == 'weekly'){
		$interval = $schedule_repeat * 604800;
	}
	if($schedule_type == 'monthly'){
		$interval = $schedule_repeat * 2592000;
	}
	if($schedule_type == 'yearly'){
		$interval = $schedule_repeat * 31536000;
	}

	$date = strtotime(date('Y-m-d')) - $interval;
	$start_date = date("Y-m-d",$date);
	//Get end date information
	$end_date =  date('Y-m-d');

	$contact_form_rule_string = isset($arrMeta['schedule_contact_form_rule']) && !empty($arrMeta['schedule_contact_form_rule'][0]) ? $arrMeta['schedule_contact_form_rule'][0] : "";
	
	if(!empty($contact_form_rule_string) && is_serialized($contact_form_rule_string)){
		$schedule_contact_form_rule = maybe_unserialize($contact_form_rule_string);
	}
	
	if(empty($schedule_contact_form_rule)){
		$schedule_contact_form_rule = get_post_meta($arrMeta['vsz_post_id'],'schedule_contact_form_rule',true);
	}
	
	$search_date_query = "AND `".VSZ_CF7_DATA_ENTRY_TABLE_NAME."`.`name` = 'submit_time' AND `".VSZ_CF7_DATA_ENTRY_TABLE_NAME."`.value between '".$start_date."' and '".$end_date." 23:59:59'";
	$innerjoin = '';
	$checkinnerjoin = 1;
	if(isset($schedule_contact_form_rule) && !empty($schedule_contact_form_rule) && is_array($schedule_contact_form_rule)){

		foreach($schedule_contact_form_rule as $retrive_data){
			if(empty($retrive_data['fields_name']) || empty($retrive_data['fields_condition']) || empty($retrive_data['fields_value']) ){
				continue;
			}
			$innerjoin .= 'INNER JOIN `'.VSZ_CF7_DATA_ENTRY_TABLE_NAME.'` as  mt'.$checkinnerjoin.' on ( `'.VSZ_CF7_DATA_ENTRY_TABLE_NAME.'`.data_id = mt'.$checkinnerjoin.'.data_id )';
			if($retrive_data['fields_condition'] != 'like'){
				$search_date_query .= " AND ( mt".$checkinnerjoin.".`name` = '".$retrive_data['fields_name']."' AND mt".$checkinnerjoin.".`value` ".$retrive_data['fields_condition']." '".$retrive_data['fields_value']."')";
			}else{
				$search_date_query .= " AND ( mt".$checkinnerjoin.".`name` = '".$retrive_data['fields_name']."' AND mt".$checkinnerjoin.".`value` ".$retrive_data['fields_condition']." '%".$retrive_data['fields_value']."%')";

			}
			$checkinnerjoin++;
		}
	}

	$query = "SELECT * FROM `".VSZ_CF7_DATA_ENTRY_TABLE_NAME."` WHERE `cf7_id` = ".$fid." AND data_id IN(SELECT * FROM (SELECT `".VSZ_CF7_DATA_ENTRY_TABLE_NAME."`.data_id FROM `".VSZ_CF7_DATA_ENTRY_TABLE_NAME."` ".$innerjoin." WHERE 1 = 1 AND `".VSZ_CF7_DATA_ENTRY_TABLE_NAME."`.`cf7_id` = ".$fid." ".$search_date_query.' '. ((!empty($ids_export)) ? " AND data_id IN(".$ids_export.")" : '')."  GROUP BY `data_id` ORDER BY ".$cf7d_entry_order_by.") temp_table) ORDER BY " . $cf7d_entry_order_by;
	

	//Execuste query
	$data = $wpdb->get_results($query);

	//Return result set
	return  $data;
}//Close export query function

/*
 * Delete the main records from the schedule created
 * Passed the Data ID's to be deleted from the 2 tables of the advanced CF7 db
 *
 * @since 1.0.3
 */
function vsz_delete_records($data){
	if(!empty($data)){
		global $wpdb;
		if(is_array($data)){
			foreach($data as $data_ids)
			{
			    $new_arr[] = $data_ids->data_id;
			}
			$imploded = implode(',', $new_arr);
			//Delete from the main table
			$delete_main_query = "DELETE from `".VSZ_CF7_DATA_TABLE_NAME."` where id IN (".$imploded.")";

			//Delete from the secondary table
			$delete_secondary_query = "DELETE from `".VSZ_CF7_DATA_ENTRY_TABLE_NAME."` where data_id IN (".$imploded.")";

			$wpdb->query($delete_main_query);
			$wpdb->query($delete_secondary_query);

		}else{
			//Delete from the main table
			$delete_main_query = "DELETE from `".VSZ_CF7_DATA_TABLE_NAME."` where id IN (".$data.")";
			//Delete from the secondary table
			$delete_secondary_query = "DELETE from `".VSZ_CF7_DATA_ENTRY_TABLE_NAME."` where data_id IN (".$data.")";
			$wpdb->query($delete_main_query);
			$wpdb->query($delete_secondary_query);
		}
	}
}